==> fvtt-ecryme-v12.0.0.zip: fvtt-ecryme/modules/common/ecryme-config.js <==

export const ECRYME_CONFIG = {

  traitTypes: {
    normal: "Normal", 
    spleen: "Spleen",
    ideal: "Ideal"
  },
  weaponTypes: {
    "melee": "ECRY.ui.melee",
    "ranged": "ECRY.ui.ranged"
  },
  traitLevel: [
    {value: -3, text: "-3"},
    {value: -2, text: "-2"},
    {value: -1, text: "-1"},
    {value: +1, text: "+1"},
    {value: +2, text: "+2"},
    {value: +3, text: "+3"}
  ],
  impactTypes: {
    physical: "ECRY.ui.physical",
    mental: "ECRY.ui.mental",
    social: "ECRY.ui.social"
  },
  impactLevels: {
    superficial: "ECRY.ui.superficial",
    light: "ECRY.ui.light",
    serious: "ECRY.ui.serious",
    major: "ECRY.ui.major"
  },
  difficulty: {
    "-1": {difficulty: "ECRY.ui.none", frequency: "ECRY.ui.none", value: "-"},
    "8": { difficulty: "ECRY.ui.troublesome", frequency: "ECRY.ui.occasional", value: 8 },
    "10": { difficulty: "ECRY.ui.difficult", frequency: "ECRY.ui.uncommon", value: 10 },
    "12": { difficulty: "ECRY.ui.verydifficult", frequency: "ECRY.ui.rare", value: 12 },
    "14": { difficulty: "ECRY.ui.extremdifficult", frequency: "ECRY.ui.veryrare", value: 14 },
    "16": { difficulty: "ECRY.ui.increddifficult", frequency: "ECRY.ui.exceptrare", value: 16 },
  },
  skillLevel: {
    "0": "0",
    "1": "1",
    "2": "2",
    "3": "3",
    "4": "4",
    "5": "5",
    "6": "6",
    "7": "7",
    "8": "8",
    "9": "9",
    "10": "10"
  },
  costUnits: {
    "ingot": {name: "ECRY.ui.ingot", value: 100000},
    "ingotin": {name: "ECRY.ui.ingotin", value: 10000},
    "goldcoin": {name: "ECRY.ui.goldcoin", value: 1000 },
    "lige": {name: "ECRY.ui.lige", value: 100 },
    "hurle": {name: "ECRY.ui.hurle", value: 10 },
    "coin": {name: "ECRY.ui.coin", value: 1 }
  },
  transcendanceOptions: {
    "execution": "ECRY.ui.execution",
    "preservation": "EC,RY.ui.preservation"
  },
  bonusMalusPersoOptions: [
    {value: "-3", label: "-3"},
    {value: "-2", label: "-2"},
    {value: "-1", label: "-1"},
    {value: "0",  label: "0"},
    {value: "+1", label: "+1"},
    {value: "+2", label: "+2"},
    {value: "+3", label: "+3"}
  ]


}

==> fvtt-ecryme-v12.0.1.zip: fvtt-ecryme/modules/common/ecryme-config.js <==

export const ECRYME_CONFIG = {

  traitTypes: {
    normal: "Normal", 
    spleen: "Spleen",
    ideal: "Ideal"
  },
  weaponTypes: {
    "melee": "ECRY.ui.melee",
    "ranged": "ECRY.ui.ranged"
  },
  traitLevel: {
    "-3":{value: "-3", text: "-3"},
    "-2":{value: "-2", text: "-2"},
    "-1":{value: "-1", text: "-1"},
    "+1":{value: "+1", text: "+1"},
    "+2":{value: "+2", text: "+2"},
    "+3":{value: "+3", text: "+3"}
  },
  impactTypes: {
    physical: "ECRY.ui.physical",
    mental: "ECRY.ui.mental",
    social: "ECRY.ui.social"
  },
  impactLevels: {
    superficial: "ECRY.ui.superficial",
    light: "ECRY.ui.light",
    serious: "ECRY.ui.serious",
    major: "ECRY.ui.major"
  },
  difficulty: {
    "-1": {difficulty: "ECRY.ui.none", frequency: "ECRY.ui.none", value: "-1"},
    "8": { difficulty: "ECRY.ui.troublesome", frequency: "ECRY.ui.occasional", value: 8 },
    "10": { difficulty: "ECRY.ui.difficult", frequency: "ECRY.ui.uncommon", value: 10 },
    "12": { difficulty: "ECRY.ui.verydifficult", frequency: "ECRY.ui.rare", value: 12 },
    "14": { difficulty: "ECRY.ui.extremdifficult", frequency: "ECRY.ui.veryrare", value: 14 },
    "16": { difficulty: "ECRY.ui.increddifficult", frequency: "ECRY.ui.exceptrare", value: 16 },
  },
  skillLevel: {
    "0": "0",
    "1": "1",
    "2": "2",
    "3": "3",
    "4": "4",
    "5": "5",
    "6": "6",
    "7": "7",
    "8": "8",
    "9": "9",
    "10": "10"
  },
  costUnits: {
    "ingot": {name: "ECRY.ui.ingot", value: 100000},
    "ingotin": {name: "ECRY.ui.ingotin", value: 10000},
    "goldcoin": {name: "ECRY.ui.goldcoin", value: 1000 },
    "lige": {name: "ECRY.ui.lige", value: 100 },
    "hurle": {name: "ECRY.ui.hurle", value: 10 },
    "coin": {name: "ECRY.ui.coin", value: 1 }
  },
  transcendanceOptions: {
    "execution": "ECRY.ui.execution",
    "preservation": "ECRY.ui.preservation"
  },
  bonusMalusPersoOptions: {
    "-3": {value: "-3", label: "-3"},
    "-2": {value: "-2", label: "-2"},
    "-1": {value: "-1", label: "-1"},
    "0":  {value: "0",  label: "0"},
    "+1": {value: "1", label: "+1"},
    "+2": {value: "2", label: "+2"},
    "+3": {value: "3", label: "+3"}
  }

}
